@@ -4,12 +4,24 @@ import sys
 import StringIO
 import tempfile
 import os
+import pdb
 
 import Image
 import ImageDraw
 import cairo
 import rsvg
 import argparse
+from images import *
+
+def open_svgstring_as_image(string, width, height):
+    try:
+        tmpfd, tmppath = tempfile.mkstemp(".svg")
+        tmpfile = os.fdopen(tmpfd, 'w')
+        tmpfile.write(string)
+        tmpfile.close()
+        return open_svg_as_image(tmppath, width, height)
+    finally:
+        os.remove(tmppath)
 
 def open_svg_as_image(fn, width, height):
     for i in range(10):
@@ -158,28 +170,28 @@ def draw_board(fen="rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR",
             bord_offset + border_width,
             title_height + bord_offset + border_width,
             )
-        draw.rectangle(rect, fill=red, outline=border_color)
+        draw.rectangle(rect, fill=border_color, outline=border_color)
         rect = (
             bord_offset + border_width + 8*sqsize,
             title_height + bord_offset,
             bord_offset + 2 * border_width + 8*sqsize,
             title_height + bord_offset + border_width,
             )
-        draw.rectangle(rect, fill=red, outline=border_color)
+        draw.rectangle(rect, fill=border_color, outline=border_color)
         rect = (
             bord_offset + border_width + 8*sqsize,
             title_height + bord_offset + border_width + 8*sqsize,
             bord_offset + 2 * border_width + 8*sqsize,
             title_height + bord_offset + 2 * border_width + 8*sqsize,
             )
-        draw.rectangle(rect, fill=red, outline=border_color)
+        draw.rectangle(rect, fill=border_color, outline=border_color)
         rect = (
             bord_offset,
             title_height + bord_offset + border_width + 8*sqsize,
             bord_offset + border_width,
             title_height + bord_offset + 2 * border_width + 8*sqsize,
             )
-        draw.rectangle(rect, fill=red, outline=border_color)
+        draw.rectangle(rect, fill=border_color, outline=border_color)
     
     # Draw the squares
     for row in range(8):
@@ -205,65 +217,62 @@ def draw_board(fen="rnbqkbnr/pppppppp/8/8/8/8/PPPPPPPP/RNBQKBNR",
         imgpos = (border_width+sqsize*(col-1),
                   title_height + border_width+sqsize*(8-row))
         if c == 'K':
-            wking = open_svg_as_image('images/white_king.svg', sqsize, sqsize)
+            wking = open_svgstring_as_image(white_king, sqsize, sqsize)
             im.paste(wking, imgpos, wking)
             col += 1
         elif c == 'Q':
-            wqueen = open_svg_as_image('images/white_queen.svg', sqsize, sqsize)
+            wqueen = open_svgstring_as_image(white_queen, sqsize, sqsize)
             im.paste(wqueen, imgpos, wqueen)
             col += 1
         elif c == 'P':
-            wpawn = open_svg_as_image('images/white_pawn.svg', sqsize, sqsize)
+            wpawn = open_svgstring_as_image(white_pawn, sqsize, sqsize)
             im.paste(wpawn, imgpos, wpawn)
             col += 1
         elif c == 'R':
-            wrook = open_svg_as_image('images/white_rook.svg', sqsize, sqsize)
+            wrook = open_svgstring_as_image(white_rook, sqsize, sqsize)
             im.paste(wrook, imgpos, wrook)
             col += 1    
         elif c == 'B':
-            wbishop = open_svg_as_image('images/white_bishop.svg', sqsize, sqsize)
+            wbishop = open_svgstring_as_image(white_bishop, sqsize, sqsize)
             im.paste(wbishop, imgpos, wbishop)
             col += 1
         elif c == 'N':
-            wknight = open_svg_as_image('images/white_knight.svg', sqsize, sqsize)
+            wknight = open_svgstring_as_image(white_knight, sqsize, sqsize)
             im.paste(wknight, imgpos, wknight)
             col += 1
             
         elif c == 'k':
-            wking = open_svg_as_image('images/black_king.svg', sqsize, sqsize)
+            wking = open_svgstring_as_image(black_king, sqsize, sqsize)
             im.paste(wking, imgpos, wking)
             col += 1
         elif c == 'q':
-            wqueen = open_svg_as_image('images/black_queen.svg', sqsize, sqsize)
+            wqueen = open_svgstring_as_image(black_queen, sqsize, sqsize)
             im.paste(wqueen, imgpos, wqueen)
             col += 1
         elif c == 'p':
-            wpawn = open_svg_as_image('images/black_pawn.svg', sqsize, sqsize)
-            im.paste(wpawn, imgpos, wpawn)
+            bpawn = open_svgstring_as_image(black_pawn, sqsize, sqsize)
+            im.paste(bpawn, imgpos, bpawn)
             col += 1
         elif c == 'r':
-            brook = open_svg_as_image('images/black_rook.svg', sqsize, sqsize)
+            brook = open_svgstring_as_image(black_rook, sqsize, sqsize)
             im.paste(brook, imgpos, brook)
-            col += 1    
+            col += 1
         elif c == 'b':
-            wbishop = open_svg_as_image('images/black_bishop.svg', sqsize, sqsize)
-            im.paste(wbishop, imgpos, wbishop)
+            bbishop = open_svgstring_as_image(black_bishop, sqsize, sqsize)
+            im.paste(bbishop, imgpos, bbishop)
             col += 1
         elif c == 'n':
-            wknight = open_svg_as_image('images/black_knight.svg', sqsize, sqsize)
-            im.paste(wknight, imgpos, wknight)
+            bknight = open_svgstring_as_image(black_knight, sqsize, sqsize)
+            im.paste(bknight, imgpos, bknight)
             col += 1  
         elif c in '12345678':
             col += int(c)
         elif c == '/':
             col = 1
             row -= 1
-        return im
-        #im.save(open('tst.png','w'))
+    return im
     
 if __name__ == '__main__':
-    print os.curdir
-    print open('images/white_king.svg').read()
     parser = argparse.ArgumentParser(
         description='Create a chess board image from a fen description')
     parser.add_argument('fen', help='Position in the fen format')
@@ -279,6 +288,5 @@ if __name__ == '__main__':
     if args.outfile == None:
         args.outfile = open(args.fen.replace('/','_') + '.png', 'w')
     
-    print args.fen
     im = draw_board(title1=args.title1, title2=args.title2, footnote=args.footnote)
     im.save(args.outfile)
\ No newline at end of file
